@@ -2,7 +2,7 @@ package Mojolicious::Plugin::Log::Any;
 
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = 'v1.0.2';
+our $VERSION = 'v1.0.3';
 
 sub register {
   my ($self, $app, $conf) = @_;
@@ -30,7 +30,7 @@ Mojolicious::Plugin::Log::Any - Use other loggers in a Mojolicious application
     my $self = shift;
     
     # Log::Any (default)
-    use Log::Any::Adapter {category => 'MyApp'}, 'Syslog';
+    use Log::Any::Adapter {category => 'MyApp', message_separator => ' '}, 'Syslog';
     $self->plugin('Log::Any');
     
     # Log::Contextual
@@ -110,6 +110,10 @@ the application name.
 
 Passed through to L<Mojo::Log::Role::AttachLogger/"attach_logger">.
 
+=item message_separator
+
+Passed through to L<Mojo::Log::Role::AttachLogger/"attach_logger">.
+
 =back
 
 =head1 BUGS
